%% FAM_FACTOR
% Define a familiarity factor to distinguish between new and old test
% items.

%% Basic familiarity factor
%
% FAM_FACTOR(aglss, 'fname') distinguishes between familiar (Old) and novel
% (New) test items.
%
% The example below generates training items based on the XY_GRAMMAR, which
% alternates Xs and Ys, and grammatical (G) test items that are either Old
% (included in the training set) or New (not included in training). 

s_xy = aglss(xy_grammar, [1 5]);

[s, famlevs] = fam_factor(s_xy, 'fam');
[s] = gram_factor(s, 'gram');

s = factorial_testsets(s, [{'fam'}, famlevs], {'gram', 'G'});
s = choose_items(s, 4, 2, [], true); % Training items eligible to use in test

disp('Training items:');
disp(format_train_items(s));

disp('Test items:');
disp(format_test_items(s));

%% Familiarity factor with specified category names
%
% FAM_FACTOR(aglss, 'fname', {'oldname', 'newname'}) specifies alternative
% names for the Old and New categories.

s = fam_factor(s_xy, 'MyFam', {'Familiar', 'Novel'});
[s] = gram_factor(s, 'gram');

s = factorial_testsets(s, {'MyFam', 'Familiar', 'Novel'}, {'gram', 'G'} );
s = choose_items(s, 4, 2, [], true);

disp('Training items:');
disp(format_train_items(s));

disp('Test items:');
disp(format_test_items(s));

%% Dummy familiarity factor
%
% The example below explicitly identifies all test items chosen by
% StimSelect as being different from any of the training items.  Without
% this factor, test items would still be different from training items in
% accordance with the default behavior of choose_items(). However, that
% fact is not explicitly indicated by default when test items are
% displayed.
s_xy = aglss(xy_grammar, [1 5]);

[s, glevs] = gram_factor(s_xy, 'gram');
[s, famlevs] = fam_factor(s, 'fam');

s = factorial_testsets(s, [{'gram'}, glevs], {'fam', 'New'});
s = choose_items(s, 4, 2);

disp('Training items:');
disp(format_train_items(s));

disp('Test items:');
disp(format_test_items(s));