function f = delete_state( f, states )
% DELETE_STATE     Delete one or more states from finite state grammar
%
% [s, newf] = delete_state( f, states )
%
% Returns the new FSG.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

links = f.links;
states = sort(states(:),'descend');
n_syms = n_symbols(f);

for curstate = states',
    % Remove links to this state
    links(links == curstate) = 0;
    
    % Renumber other states
    links(links > curstate) = links(links > curstate) - 1;
end
links(states,:) = [];    % Delete the states

if isempty(links),
    links = zeros(1, n_syms);    % Keep empty State 1 to represent n_syms
end
f.links = links;
[nil, f] = upstream_states(f, [], [], 'reset'); % recompute upstream info