function isg = isgrammatical(g, s)
% ISGRAMMATICAL Test whether strings are grammatical
%
% L = ISGRAMMATICAL(FSG, S) returns a logical vector indicating which
% strings in S can be parsed by the specified finite state grammar.
%
%   S can be a character array or a cell array of strings.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%   2013/09/02 Check that parse finished on end state
%   1.2  2007/09/17 13:15:44

s = cellstr(s);
n = numel(s);
isg = false(n, 1);  % space for G or NG indicators
for i = 1:n,
    [states, nil, leftover] = parse_string(g, s{i});
    isg(i) = isempty(leftover) && states(end) < 0;
end
