function [s, f] = known_strings(f, state, s)
% KNOWN_STRINGS     Set/get strings that have been parsed from a state
%
% f should be a FSG
% state can be a scalar or a vector of state indices
%
% s can be a cellstr or a character array if s is a scalar, otherwise a
% cell array with one element for each element of state, containing a
% cell array of strings for that state
%
% uniqueness is guaranteed only if state is a scalar

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

if nargin < 2 || isempty(state),
    state = [1:n_states(f)];
end

if nargin > 2,
    if isscalar(state),
        f.known_strings{state} = unique(cellstr(s));
    else
        f.known_strings(state) = s;
    end
else
    % Return a cell array of cell arrays
    n_known = length(f.known_strings);
    if isscalar(state),
        if state > n_known,
            s = {};
        else
            s = f.known_strings{state};
        end
    else
        s = f.known_strings(state(state <= n_known));
        if any(state > n_known),
            s(state(state > n_known)) = repmat({{}}, sum(state > n_known), 1);
        end
    end
end
    
