function [states, f, leftover] = parse_string( f, s, cont_flag );
% PARSE_STRING  Attempt to parse a string with a finite state grammar
%
% [states, fsg, leftover] = parse_string(fsg, string, [cont_flag])
%
% f is reset to the start state before attempting to parse string s, unless 
% cont_flag is specified and non-zero, in which case parsing continues from the
% current state of f
%
% The states returned is a vector of states passed through during the
% parse, in order.  If the parse is successful, the length of this vector
% will be 2 more than the length of s, and the last item will be -1
%
% The FSG returned has its prefix value set to the part of the input string
% which is successfully parsed, if any.
%
% The leftover returned is the part of the input string remaining when
% parsing fails, or the empty string if parsing is successful.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

if nargin < 3,
    cont_flag = 0;
end

if ~cont_flag,
    % start in start state, etc.
    f = reset_state( f );
end

states = state(f);
for i = 1:length(s)+1,
%     cur_state = f.state;
    if i > length(s),
        x = '';  % Try to parse end-of-string
    else
        x = s(i);   % Try to parse next character
    end
    [new_s, f] = parse_symbol(f, x);
    if new_s == 0,
%         new_s = f.state;
        leftover = s(i:end);
        return
    end
    states(end+1) = state(f);
end
leftover = '';
return
