function [new_s, f] = parse_symbol( f, x )
% PARSE_SYMBOL  Attempt to parse a given symbol by finite state grammar
%
% [next_state, newf] = parse_symbol( f, x )
%
% Attempt to parse symbol x in current state of finite state grammar f
%   x can either be a symbol character ('' = end-of-string), or a symbol index 1..k (1 =
%   end-of-string)
%
% The null string is represented by '.'
%
% Returns new_s = 0 if parse fails (no transition from current state
% for symbol x), but leaves f in current state

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

s_index = symbol_index( f, x );

if s_index > n_symbols(f),
    error( 'Attempt to exceed number of valid symbols for FSG' );
end

new_s = f.links(f.state, s_index);

if new_s ~= 0,
    if s_index == 1,
        % end-of-string
        new_s = -1;     % Halted at end of valid string, stored as prefix
        if isempty(f.prefix),
            f.prefix = '.'; % Dot is placeholder for empty parsed string
        end
    else
        if ~strcmp(f.symbols, ''),
            f.prefix = [f.prefix, f.symbols(s_index-1)];
        end
    end
    [new_s, f] = state(f, new_s);   % update grammar's state
end
return
