function ok = test_fsg();
% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%   1.2  2007/09/17 13:15:44

ok = 1;

% FSG with single node, accept X*
x = fsg(2);
[nil, x] = symbols(x, 'X');
[nil, x] = link(x, 1, '', -1);   % Accept end-of-string
[nil, x] = link(x, 1, 'X', 1);
g_x = grammatical_strings(x, [0, 3]);
g_x = sortrows(g_x);
if strcmp(g_x, char('.','X','XX','XXX')),
    display('g_x OK');
else
    display(sortrows(g_x));
    warning('g_x NOK');
    ok = 0;
end

% FSG with single node, accept {X,Y}*
xy = fsg([-1, 1, 1], 'XY');
g_xy = grammatical_strings(xy, [0, 2]);
g_xy = sortrows(g_xy);
if strcmp(g_xy, char('.','X','XX', 'XY', 'Y', 'YX', 'YY')),
    display('g_xy OK');
else
    display(sortrows(g_xy));
    warning('g_xy NOK');
    ok = 0;
end

% FSG with two nodes, accepts X(YX)*
xyx = fsg([0, 2, 0; -1, 0, 1], 'XY');
g_xyx = grammatical_strings(xyx, [0, 4]);
g_xyx = sortrows(g_xyx);
if strcmp(g_xyx, char('X','XYX')),
    display('g_xyx OK');
else
    display(sortrows(g_xyx));
    warning('g_xyx NOK');
    ok = 0;
end

% Try parsing some things with xyx
[s, f, leftover] = parse_string(xyx, 'X');
if s(end) < 0,
    disp('xyx(X) OK');
else
    warning('xyx(X) NOK');
    ok = 0;
end
[s, f, leftover] = parse_string(xyx, 'XYX');
if s(end) < 0,
    disp('xyx(XYX) OK');
else
    warning('xyx(XYX) NOK');
    ok = 0;
end
[s, f, leftover] = parse_string(xyx, 'XYXYX');
if s(end) < 0,
    disp('xyx(XYXYX) OK');
else
    warning('xyx(XYXYX) NOK');
    ok = 0;
end
[s, f, leftover] = parse_string(xyx, 'XY');
if s(end) > 0,
    disp('~xyx(XY) OK');
else
    warning('~xyx(XY) NOK');
    ok = 0;
end

% Try to induce a grammar
f = fsg([],'XY');
f = induce1(f, char('XY','XYXX'));
if link(f) == [0, 2, 0; 0, 0, 3; -1, 3, 0],
    disp('fsg(''XY'', ''XYXX'') OK');
else
    warning('fsg(''XY'', ''XYXX'') NOK');
    display(f);
    ok = 0;
end
% Check that it generates the right strings
g = grammatical_strings(f, 5);
if g == char('XY', 'XYX', 'XYXX', 'XYXXX'),
    disp('=> lang OK');
else
    warning('lang fsg(''XY'', ''XYXX'') NOK');
    disp(g);
    ok = 0;
end

% Try Peigneux et al. grammar
f = fsg([], 'FVMTRX');
[nil, f] = link(f, 1, 'F', 2);
[nil, f] = link(f, 1, 'T', 3);
[nil, f] = link(f, 3, 'M', 2);
[nil, f] = link(f, 2, 'V', 4);
[nil, f] = link(f, 3, 'X', 4);
[nil, f] = link(f, 4, 'F', 5);
[nil, f] = link(f, 4, 'R', 6);
[nil, f] = link(f, 5, 'R', 5);
[nil, f] = link(f, 5, 'T', 7);
[nil, f] = link(f, 6, 'M', 6);
[nil, f] = link(f, 6, 'X', 8);
[nil, f] = link(f, 7, '', -1);
[nil, f] = link(f, 7, 'M', 6);
[nil, f] = link(f, 7, 'R', 6);
[nil, f] = link(f, 7, 'X', 8);
[nil, f] = link(f, 8, '', -1);
[nil, f] = link(f, 8, 'V', 9);
[nil, f] = link(f, 9, '', -1);
[nil, f] = link(f, 9, 'R', 6);
g = grammatical_strings(f, 7);
if size(g, 1) == 63,
    disp('size fsg(Peigneux) OK');
else
    warning('size fsg(Peigneux) NOK');
    size(g)
    ok = 0;
end
% Try to build a grammar from the strings of f
training = g(randperm(size(g,1)),:);
f1 = fsg(training, @induce1);
% f1 = induce1(f, g(randperm(size(g,1)),:), @induce1)
g1 = grammatical_strings(f1, [4,7]);
size(g1)

% Try to build one also using induce2
f2 = fsg(training, @induce2);
g2 = grammatical_strings(f2, [4,7]);
size(g2)


% Check known_string stuff
f = fsg([-1; -1],1);
[nil, f] = known_strings(f, 1, cellstr('one'));
[nil, f] = known_strings(f, 2, cellstr('two'));
s = find_known_string(f, 'two');
if s == 2,
    disp('known_string OK');
else
    warning('known_string NOK');
    disp(s);
    ok = 0;
end


% Try to build one using induce3
f3 = fsg(char('XY','Y','YY'), @induce3);
g3 = grammatical_strings(f3, 7);
if g3 == char('XY','Y','YY'),
    disp('induce3 OK');
else
    warning('induce3 NOK');
    ok = 0;
end

f3 = fsg(char('XY','YY', 'Y'), @induce3);
g3 = grammatical_strings(f3, 7);
if g3 == char('X','XY','Y','YY'),
    disp('induce3_2 OK');
else
    warning('induce3_2 NOK');
    ok = 0;
end

f3 = fsg(training, @induce3);
g3 = grammatical_strings(f3, [4,7]);
size(g3)


return