function [s, f] = symbols( f, s )
%SYMBOLS Get or set symbols valid for a finite state grammar
%
% [s, newf] = symbols( fsg, [symbols] )
%
% If symbols are specified, the output argument newf is a copy of the original
% fsg f except that newf has the specified symbol set

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

if nargin > 1,
    if length(s) ~= n_symbols(f)-1, % end-of-string is extra symbol
        error( 'Change in number of symbols is not supported for FSG!' );
    else
        f.symbols = s;
        f = reset_state(f);
    end
else
    s = f.symbols;
end

return
