function k = string_complexity(s, n_syms)
% STRING_COMPLEXITY     Complexity of a string relative to an alphabet
%
% K = STRING_COMPLEXITY(S, N_SYMS) returns the number of bits required to
%   specify a sequence of symbols having the length of character array
%   S, assuming that symbols are chosen with equal probability from a set
%   of size N_SYMS.
%
% A self-delimiting code is assumed, specifying L = the length of S (as a
% symbol sequence), followed by a sequence of L binary numbers specifying
% the symbols of S, sym(1), ..., sym(L), identifying which of n_syms
% symbols occurs at each position of S.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

if ischar(s),
    len = size(s,2);    % Length of S
    k = prefix_code(len) + (len * ceil(log2(n_syms)));
else
    error('STRING_COMPLEXITY called with non-string');
end