function chunks = chunk_names(syms, max_chsize)
% CHUNK_NAMES - Return possible chunks composed of a set of symbols
%
% CHUNK_NAMES(SYMS, L) returns a cell array with cell i containing a string
% array listing all possible chunks of length i composed of letters
% specified in the string SYMS.  L determines the maximum chunk length of
% interest.
%
% EXAMPLE: chunk_names('AB',2) returns
%   {['A';'B'],['AA';'BA';'AB';'BB']}

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%   1.1  2007/09/07 11:17:51

chunks = cell(max_chsize, 1);   % allocate space
for chunk_size = 1:max_chsize,
    if chunk_size == 1,
        chunks{chunk_size} = syms';
    else
        chunks{chunk_size} = syms(fullfact(...
            repmat(length(syms), chunk_size, 1)));
    end
end

end
