function yi = interp(x, y, xi)
% INTERP - Linear interpolation of scalars, quickly
%
% INTERP(X, Y, XI) interpolates scalar XI onto the piece-wise linear
% function Y, described by vectors X and Y, which must be the same length.
% X must be monotonically increasing.
%
% If XI is outside the range of X, the value NaN is returned.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

if xi < x(1) || xi > x(end) || length(x) <= 1,
    yi = NaN;
    return
end

% Find the relevant piece of the function.
idx2 = find(x >= xi, 1);
if (idx2 == 1),
    idx2 = 2;
end
idx1 = idx2-1;

% Interpolate.
yi = y(idx1) + (y(idx2) - y(idx1)) .* ...
    (xi - x(idx1)) ./ (x(idx2) - x(idx1));

end