function stack = make_stack(arg)
% MAKE_STACK  Makes a structure of function handles implementing a stack
%
% STACK = MAKE_STACK() returns a structure STACK with three fields set to
% function handles with the following functions:
%   STACK.INIT() removes all data and initializes an empty stack array
%   STACK.INIT( vector ) initializes the stack to the items in VECTOR, in
%       order
%   STACK.PUSH( data ) pushes the arguments onto the stack
%   STACK.POP() removes the first item from the stack and returns it
%   STACK.CONTENTS() returns the raw stack contents
%
% STACK = MAKE_STACK('cells') creates a STACK of cells

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%   1.1  2007/09/13 10:41:51

if nargin && strcmp(arg,'cells'),
    stackdata = {};
    stack.init = @cellstackinit;
    stack.push = @cellstackpush;
    stack.pop = @cellstackpop;
    stack.contents = @stackcontents;
    stack.isempty = @stackisempty;
else
    stackdata = [];
    stack.init = @stackinit;
    stack.push = @stackpush;
    stack.pop = @stackpop;
    stack.contents = @stackcontents;
    stack.isempty = @stackisempty;
end

    function s = stackcontents()
        s = stackdata;
    end

    function b = stackisempty()
        b = isempty(stackdata);
    end

    function stackinit(varargin)
        if nargin,
            d = [varargin{:}];
        else
            d = [];
        end
        stackdata = d;
    end

    function stackpush(varargin)
        stackdata = [varargin{:}, stackdata];
    end

    function d = stackpop
        if isempty(stackdata),
            d = [];
        else
            d = stackdata(1);
            stackdata(1) = [];
        end
    end


    function cellstackinit(varargin)
        if nargin,
            d = varargin;
        else
            d = {};
        end
        stackdata = d;
    end

    function cellstackpush(varargin)
        stackdata = {varargin{:}, stackdata{:}};
    end

    function d = cellstackpop
        if isempty(stackdata),
            d = [];
        else
            d = stackdata{1};
            stackdata(1) = [];
        end
    end
end