function [c,a_match,b_match] = union_sorted(a,b)
%UNION_SORTED  Set union of sorted sets.
% UNION_SORTED(A,B), where A and B are cell arrays of strings, returns the
% combined values from A and B with no repetitions.  A (and B) must be
% sorted and unique, and the result will be sorted and unique.
%
% % [C,A_MATCH,B_MATCH] = UNION_SORTED(A,B) also returns
% %   A_MATCH = MATCH_SORTED(A,C)
% %   B_MATCH = MATCH_SORTED(B,C)
%
% Examples:
%   union_sorted({'abc','help','hill'}, {'help','hill','him'})
%   [c,a_match,b_match] = ...
%       union_sorted({'abc','help','hill'}, {'help','hill','him'})

% Copyright 2007 Todd M. Bailey
% Written by Todd M. Bailey, based on Tom Minka's function for numeric
% sets (in the Lightspeed Toolbox).
%
% This file is part of AGL StimSelect (AGLSS), but is covered by a
% Microsoft Research Shared Source license agreement (MSR-SSLA).  You
% should have received a copy of that agreement along with this file.  If
% not, see
% http://research.microsoft.com/research/downloads/Details/92f6d4ed-4df4-43
% 69-9b92-89b28da8795d/License.txt .
% 
% This file is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% MSR-SSLA for more details.
%
% You may use, copy, reproduce, and distribute this Software for any
% non-commercial purpose, subject to the restrictions in the MSR-SSLA. 
%
%
% This file is derived from a file of the same name in the LightSpeed
% Toolbox, listed as "Fast subroutines for Matlab programs" at
% http://research.microsoft.com/research/downloads .
%
% This file has been changed from its original form, on 4 September 2007, 
% to work on cell arrays using a merge of two sorted lists.

% merge the two sorted lists.
if nargout <= 1
    [tf,loc] = ismember_sorted(a,b);
    nm = find(loc < 0);
    c = cell(numel(b) + numel(nm), 1);
    nxtB = 1;
    nxtC = 1;
    for i = 1:numel(nm),
        nB = -loc(nm(i)) - nxtB;
        c(nxtC:nxtC+nB-1) = b(nxtB:nxtB+nB-1);
        c(nxtC+nB) = a(nm(i));
        nxtC = nxtC + nB + 1;
        nxtB = nxtB + nB;
    end
    nB = numel(b) - nxtB + 1;
    c(nxtC:nxtC+nB-1) = b(nxtB:nxtB+nB-1);
            
% %   c = sort([a(~ismember_sorted(a,b)) b]);
else
    error('@cell::union_sorted::nargout', ...
        'Additional output arguments not supported for cell arrays');
% %   [tf,loc] = ismember_sorted(a,b);
% %   [c,i] = sort([a(~tf) b]);
% %   nc = length(c);
% %   nb = length(b);
% %   na = length(a);
% %   b_match = i((nc-nb+1):nc);
% %   a_match = zeros(1,na);
% %   a_match(~tf) = i(1:(nc-nb));
% %   a_match(tf) = b_match(loc(tf));
end
