function [tf,loc] = ismember_sorted(a,s)
%ISMEMBER_SORTED   True for member of sorted set.
% ISMEMBER_SORTED(A,S) for the vector A returns an array of the same size as A
% containing 1 where the elements of A are in the set S and 0 otherwise.
% A and S must be sorted and cannot contain NaN.
%
% [TF,LOC] = ISMEMBER_SORTED(A,S) also returns an index array LOC where
% LOC(i) is the index in S which matches A(i) (highest if there are ties)
% or 0 if there is no such index.
%
% See also ISMEMBER, MATCH_SORTED, INTERSECT_SORTED, SETDIFF_SORTED, UNION_SORTED.

% Written by Tom Minka
% (c) Microsoft Corporation. All rights reserved.

% This file is part of AGL StimSelect (AGLSS), but is covered by a
% Microsoft Research Shared Source license agreement (MSR-SSLA).  You
% should have received a copy of that agreement along with this file.  If
% not, see
% http://research.microsoft.com/research/downloads/Details/92f6d4ed-4df4-43
% 69-9b92-89b28da8795d/License.txt .
% 
% This file is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% MSR-SSLA for more details.
%
% You may use, copy, reproduce, and distribute this Software for any
% non-commercial purpose, subject to the restrictions in the MSR-SSLA. 
%
%
% This file was originally downloaded as part of the LightSpeed Toolbox,
% listed as "Fast subroutines for Matlab programs" at
% http://research.microsoft.com/research/downloads .
%
% This file has been changed from its original form, on 4 September 2007, by
% the addition of this license information.


% The internal function ismembc comes from ismember.m

if nargout < 2
  tf = ismembc(a,s);
else
  loc = ismembc2(a,s);
  tf = (loc > 0);
end
