function [c,a_match,b_match] = union_sorted(a,b)
%UNION_SORTED  Set union of sorted sets.
% UNION_SORTED(A,B) where A and B are vectors returns the combined values
% from A and B with no repetitions.  A (and B) must be sorted and unique, and 
% the result will be sorted and unique.
%
% [C,A_MATCH,B_MATCH] = UNION_SORTED(A,B) also returns
%   A_MATCH = MATCH_SORTED(A,C)
%   B_MATCH = MATCH_SORTED(B,C)
%
% Examples:
%   union_sorted([10 20 30], [20 30 40])
%   [c,a_match,b_match] = union_sorted([10 20 30], [20 30 40])

% Written by Tom Minka
% (c) Microsoft Corporation. All rights reserved.

% This file is part of AGL StimSelect (AGLSS), but is covered by a
% Microsoft Research Shared Source license agreement (MSR-SSLA).  You
% should have received a copy of that agreement along with this file.  If
% not, see
% http://research.microsoft.com/research/downloads/Details/92f6d4ed-4df4-43
% 69-9b92-89b28da8795d/License.txt .
% 
% This file is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% MSR-SSLA for more details.
%
% You may use, copy, reproduce, and distribute this Software for any
% non-commercial purpose, subject to the restrictions in the MSR-SSLA. 
%
%
% This file was originally downloaded as part of the LightSpeed Toolbox,
% listed as "Fast subroutines for Matlab programs" at
% http://research.microsoft.com/research/downloads .
%
% This file has been changed from its original form, on 4 September 2007, by
% the addition of this license information.

% instead of a full sort, you could do a merge of the two sorted lists.
if nargout <= 1
  c = sort([a(~ismember_sorted(a,b)) b]);
else
  [tf,loc] = ismember_sorted(a,b);
  [c,i] = sort([a(~tf) b]);
  nc = length(c);
  nb = length(b);
  na = length(a);
  b_match = i((nc-nb+1):nc);
  a_match = zeros(1,na);
  a_match(~tf) = i(1:(nc-nb));
  a_match(tf) = b_match(loc(tf));
end
