function s = choose_more_items(s, n_train, n_test, headstart, testfam)
% AGLSS/choose_more_items - Choose further AGL stimulus items
%
% choose_more_items(aglss, N_T, N_S, N_T0, TF_familiar)
%  Chooses additional training items and/or test items for an AGLSS object.  
%
% See AGLSS/choose_items.

% Copyright 2013 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

initialize = false;

if nargin < 5,
    testfam = false;
end

if nargin < 4 || isempty(headstart),
    headstart = min(3, n_train);
else
    if n_train < headstart,
        error('StimSelect:ChooseMoreItems:LargeHeadStart', ...
            'Headstart larger than total training items');
    end
end

if nargin < 3,
    n_test = 0;
end

if isempty(s.train) || ...
        (s.train.n_items == 0 && s.test.testsets(1).n_items == 0),
    error('StimSelect:ChooseMoreItems:NotInitialized', ...
        'Expected prior items from AGLSS/choose_items');
end

s = choose_items(s, n_train, n_test, headstart, testfam, initialize);

end
