function str = format_test_items(s, varargin)
% AGLSS/FORMAT_TEST_ITEMS - Format AGL test items for printout
%
% FORMAT_TEST_ITEMS(aglss)
% FORMAT_TEST_ITEMS(S, I, 'detail')
% FORMAT_TEST_ITEMS(S, I, 'summary')
%   Returns a string describing test items contained in an AGLSS
%   object.  The test items must have already been chosen by a prior
%   call to CHOOSE_ITEMS.
%
%   If the second argument is 'detail', or is not given, information is
%   returned for each item of each test set.
%
%   If the third argument is 'summary', information is aggregated across
%   the items within each test set.
%
% SEE ALSO: choose_items, format_train_items, format_test_items

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

if isempty(s.test),
    error('StimSelect:NoTestItems', ...
        'No test items -- use CHOOSE_ITEMS to select training and test items');
else
    str = format_test_items(s.test, s.items, varargin{:});
end

end
