function s = items_init(s, reset)
% AGLSS/ITEMS_INIT - Initialize set of potential items in AGLSS object
%
% ITEMS_INIT(aglss)
% ITEMS_INIT(aglss, 'reset')
%
% SEE ALSO: itemset_init

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

if nargin < 2,
    if isempty(s.fsg),
        error('StimSelect:Itemset_Init:NoGrammar', ...
            'Must specify grammar before initializing potential items');
    end
    if isempty(s.items),
        if isempty(s.itemnames),
            % names not directly specified, use grammar to generate them
            [strings, isG] = generate_sample_strings(s.fsg, s.minmaxlen, s.max_items);
            [s.items, s.isG] = itemset_init(strings, isG);
        else
            % use specified names
            [s.items, s.isG] = itemset_init(s.itemnames, s.isG);
            % get new order of item names, to match isG
            s.itemnames = {s.items.item.name}';
        end
    end
% %     s = chunks_init(s);
else
    if strcmpi(reset, 'reset'),
        s.items = [];
        s.isG = logical([]);
        s = chunks_init(s, 'reset');
        s.factorset = factorset();
    else
        error('StimSelect:Items_Init:UnknownArg', ...
            'Unrecognized argument');
    end
end

end
