function g = item_chnov_fit(vals, tgt)
% ITEM_CHNOV_FIT - Compute goodness of fit for chunk novelty
%
% ITEM_CHNOV_FIT(VALS, TGT) 
%   Computes goodness of fit statistics for chunk novelty values VALS with
%   respect to the target value TGT.
%
% The first dimension of VALS is assumed to correspond to items.  If VALS
% is not a column vector, fitness values are computed for each element of
% VALS, and they are summed across all dimensions but the first.  
%
% Values should be in the range 0-1.
%
% The return value is a column vector whose length = size(VALS, 1).

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

siz = size(vals);
if length(siz) ~= 2 || siz(2) ~= 1,
    change_shape = true;
    vals = vals(:);
else
    change_shape = false;
end
tgt = tgt .* ones(size(vals));

[g_tot, g_mat] = likelihoodchi2([vals 1-vals], [tgt 1-tgt]);
g = sum(g_mat, 2);

if change_shape,
    g = reshape(g, siz(1), []);
    g = sum(g, 2);  % sum up 
end

end