function [s, catnames] = dummy_fam_factor(s, fname, catnames)
% DUMMY_FAM_FACTOR - Define a StimSelect dummy familiarity factor
%
% DUMMY_FAM_FACTOR(aglss, 'fname', N)
%   OBSOLETE. Defines a factor structure with a single level, called 'New'
%   by default, which imposes no constraints at all on AGL test items. This
%   degenerate factor can be combined factorially with other factors.
%
%   The first argument should be an AGLSS object.  It is modified and
%   returned.
%
%   FNAME is the name of the factor.
%
%   N is an optional cell array with a string naming the one level of this
%   factor.  If not supplied, it is called 'New'.
%
% [S,N] = DUMMY_FAM_FACTOR(...)
%   Returns a cell array with a single strings naming the dummy category.
%   This is possibly useful if N is not specified as an input argument, to
%   get a list containing the default name assigned.
%
% Formerly useful for automatically flagging test items generated by
% StimSelect as being 'new' rather than 'old' items, to contrast them from
% any 'old' items that might be added manually.  The test items proposed by
% StimSelect used to always be 'new' in the sense that they were always
% different from any of the training items.
%
% This factor can still be used, but will not work if choose_items() is
% called with a testfam parameter = true. Better to use the 'New' factor
% level of the familiarity factor fam_factor.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

if nargin < 3,
    catnames = {'New'};
end
f = factor_def(catnames{1}, factorlevel());

s = factor(s, fname, f );

end
