function f = item_sim_update_func(sim_func, varargin)
% item_sim_update_func - Set extra arguments for item similarity function
%
% U = item_sim_update_func(F, A1, ..., An) returns a handle to an item
% similarity function which will update the .sim field of item J with
% the value obtained by calling the specified similarity function F
% as F(I, J, A1, ..., An), where I is a new training item.
%
% The item similarity function U expects to be called as:
% A = U(A, T, I)
% where A is a structure array of items to be updated,
% T is a structure array of training items, 
% and I is an individual training item that has just been added to the
% training set.  

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

    f = @item_sim_update;
    return

    function items = item_sim_update(items, fname, train, newtrain)
        % item_sim_update - update similarity to training
        %
        % A = item_sim_update(A, 'factor', T, I) updates each item in the
        % structure array A to reflect the addition of items I to the
        % training set T.  
        %
        % This function assumes that T.sim has already been updated.

        % Compute total similarity between potential test items and the new
        % training item(s)
        s = sim_func({newtrain.name}, {items.name}, varargin{:});
        s_sum = sum(s, 1)';

        % Compute new mean similarity of each potential test item to all
        % training items
        new_n = train.n_items;
        old_n = new_n - length(newtrain);
        if old_n > 0,
            old_sim = item_val(items, fname);
            s_sum = s_sum + cat(1, old_sim{:}) .* old_n;
        end
        new_mean = s_sum ./ new_n;
        items = item_val(items, fname, new_mean);

%         [n_newtrain, n_updates] = size(s);
%         for i = 1:n_updates,
%             items(i) = item_val(items(i), fname, s(:,i));
% %             items(i).sim(end+1 : end+n_newtrain) = s(:,i);
%             % NB Possibly item update functions would be faster if the
%             % information for all items was put in a single large structure
%             % (e.g. one big similarity matrix) rather than within structures
%             % for each item...?  BUT, this is harder to "undo" after
%             % tentative addition of trial new training item, so we leave it
%             % copy out the relevant info for each individual item.
%         end
    end
end
