function [g, training, test_items] = pothos_bailey_grammar()
%% pothos_bailey_grammar    FSG for Pothos & Bailey (2000)
%
% [f, training, test_items] = pothos_bailey_grammar()
%   Returns an FSG object specifying the grammar used by Pothos & Bailey
%   (2000), along with character arrays listing the training and test items
%   used in the Pothos & Bailey study.  The same grammar (with slightly
%   different items) was used by Knowlton & Squire (1996, Exp. 1).

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

g = knowlton_squire_grammar();

% Training items, in alphabetical order
training = char( ...
    'VJ', ...
    'VJTVJ', ...    % [Should have been VTVJ to match K&S]
    'VJTVTV', ...
    'VJTVX', ...
    'VJTVXJ', ...
    'VJTXVJ', ...
    'VT', ...
    'VXJJ', ...
    'VXJJJJ', ...
    'XVJTVJ', ...
    'XVT', ...
    'XVX', ...
    'XVXJ', ...
    'XVXJJ', ...
    'XVXJJJ', ...
    'XXVJ', ...
    'XXVT', ...
    'XXVXJ', ...
    'XXVXJJ', ...
    'XXXVT', ...
    'XXXVTV', ...
    'XXXVX', ...
    'XXXXVX' );

% Test items
test_items = char( ...
    'JXVT', ...
    'TVJ', ...
    'VJJXVT', ...
    'VJTV', ...
    'VJTVT', ...
    'VJTXVX', ...
    'VTV', ...
    'VTVJ', ...
    'VTVJJ', ...    % Appeared twice in the test set, but scored only once
    'VX', ...
    'VXJ', ...
    'VXJJX', ...
    'VXJTJ', ...
    'VXVJ', ...
    'XJJ', ...
    'XVJTVT', ...
    'XVJTVX', ...
    'XVTV', ...
    'XVTVJ', ...
    'XVTVJJ', ...   % Replaces K&S's second occurrence of XVTVJ
    'XVXT', ...
    'XVXV', ...
    'XVXVJ', ...
    'XXJJ', ...
    'XXTX', ...
    'XXV', ...
    'XXVJJJ', ...
    'XXVTV', ...
    'XXVTVJ', ...
    'XXVVJJ', ...
    'XXVXJ' );

return
end
