function g = reber_grammar()
%% reber_grammar    Return a FSG object for the grammar from Reber (19XX).
%
% reber_grammar()
%   Returns a deterministic version of Reber's grammar.  This generates the
%   same language as Reber's original nondeterministic grammar.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

syms = 'MRSVX';     % Symbols accepted by this grammar
n_states = 7;       % Number of states in the grammar

g = fsg([], syms);    % Create an FSG object for these symbols
% Initialize required number of states
for i = 1:n_states-1,
    [nil, g] = add_state( g );
end
% Specify links (FSG, from_state, symbol, to_state)
[nil, g] = link(g, 1, 'M', 2);
[nil, g] = link(g, 1, 'V', 3);
[nil, g] = link(g, 2, 'S', 2);
[nil, g] = link(g, 2, 'V', 4);
[nil, g] = link(g, 3, 'X', 5);
[nil, g] = link(g, 4, 'R', 3);
[nil, g] = link(g, 4, 'S', 6);
[nil, g] = link(g, 4, '', -1);  % terminal state
[nil, g] = link(g, 5, 'S', 2);
[nil, g] = link(g, 5, 'V', 4);
[nil, g] = link(g, 5, 'M', 6);
[nil, g] = link(g, 5, 'R', 7);
[nil, g] = link(g, 5, '', -1);  % terminal state
[nil, g] = link(g, 6, '', -1);  % terminal state
[nil, g] = link(g, 7, 'M', 6);
[nil, g] = link(g, 7, 'R', 7);
[nil, g] = link(g, 7, '', -1);  % terminal state

return
end
