function t = add_item_field(t, fname, val, fupdate)
% ADD_FIELD - Add a named field to an item structure
%
% T = add_field(T, N, V, U)
%
% Adds the field named N (a character string) to the structure
% T.item_struct, and adds field update function U (an optional function
% handle) to T.update_func.
% Field N is initialized to the value V.
%
% If specified, U should be a handle to a function of the form
% A = U(A, T, I)
% where A is a structure array of items to be updated,
% T is a structure array of training items, 
% and I is an individual training item that has just been added to the
% training set.  
% The function U should return A, after making any
% desired modifications.
%
% U can be ommitted or given as [] if not needed.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

t.item_struct.(fname) = val;

if nargin > 3,
    if ~isempty(fupdate),
        t.update_func{end+1} = fupdate;
    end
end

end