function v = item_val(item, field, val)
% ITEM_VAL - Get or set item values for a given factor
%
% Syntax
%   ITEM_VAL(ITEM_ARRAY, 'factor_name')
%   ITEM_VAL(ITEM_ARRAY, 'factor_name', VALUES)
%
% ITEM_VAL(ITEM_ARRAY, 'factor_name')
%   Returns the value(s) associated with factor factor_name that are
%   assigned to the item(s) in ITEM_ARRAY.  The returned value is either a
%   cell array the same size as ITEM_ARRAY, or a simple scalar if
%   ITEM_ARRAY has length 1.
%
% ITEM_VAL(ITEM_ARRAY, 'factor_name', VALUES)
%   Sets the value fields associated with the named factor in ITEM_ARRAY to
%   the corresponding cell in VALUES.
%
%   If VALUES is a scalar, it is copied into the appropriate field of all
%   elements of ITEM_ARRAY.  If the length of ITEM_ARRAY exceeds 1, then
%   VALUES should be a cell array or vector of the same size.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

field = lower(field);
if nargin < 3,
    v = {item.(field)};
else
    if length(item) == 1,
        item.(field) = val;
    elseif isscalar(val),
        [item.(field)] = deal(val);
    elseif iscell(val),
        [item.(field)] = val{:};
    else
        for i=1:numel(val),
            item(i).(field) = val(i);
        end
    end
    v = item;
end

end