function s = format_train_items(train, items)
% FORMAT_TRAIN_ITEMS - Format AGL training items for printout.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

max_item_len = max(cellfun(@length, {items.item.name}));
item_num_fmt = '      %02d';
item_name_fmt = sprintf(' %%%ds', max_item_len+1);

% Print each training item
s = '';
h = '';
item_idx = find(train.items);
for item_num = 1:train.n_items,
    [cur_s, cur_h] = headed_data(item_num_fmt, item_num, ...
        ' %s', ' Itm_num' );
    s = [s, cur_s];
    if item_num == 1,
        h = [h, cur_h];
    end

    item = items.item(item_idx(item_num));

    [cur_s, cur_h] = headed_data(item_name_fmt, item.name, ...
        item_name_fmt, ' Itm_name' );
    s = [s, cur_s];
    if item_num == 1,
        h = [h, cur_h];
    end
    s = [s, sprintf('\n')];
end
h = [h, sprintf('\n')];
s = [h, s];

end

% Format data, including vectors, and generate appropriate number of
% headers.
function [s, h] = headed_data(data_fmt, data, hdr_fmt, hdr_base);
if ischar(data),
    n = size(data,1);
else
    n = numel(data);
end
if n > 1,
    h = '';
    for i = 1:n,
        h = [h, sprintf(hdr_fmt, ...
            sprintf([hdr_base, '_%d'], i))];
    end
else
    h = sprintf(hdr_fmt, hdr_base);
end
h_width = round(length(h) / n);

if iscell(data),
    for i = 1:numel(data),
        if isempty(data{i}),
            data{i} = NaN;
        end
    end
    data = cat(2, data{:});
end
s = sprintf(data_fmt, data);    % format is used repeatedly for vectors
data_width = round(length(s) / n);

switch sign(data_width - h_width),
    case -1,
        [s, h] = headed_data(...
            [repmat(' ', 1, h_width - data_width), data_fmt], data, ...
            hdr_fmt, hdr_base);
    case +1,
        [s, h] = headed_data(...
            data_fmt, data, ...
            [repmat(' ', 1, data_width - h_width), hdr_fmt], hdr_base);
end

end