function train = add_train_exclusion(train, xname, f)
% ADD_TRAIN_EXCLUSION - Add an exclusion function to limit training items
%
% T = add_train_exclusion(T, N, F)
%
% T is a train item structure
% N is the name of the exclusion (a character vector, not necessarily
%   unique)
% F is a handle to a function that is compatible with the form 
% [X, R] = F(I, T, S).  The function will be passed an item I to evaluate,
% along with the training set so far, T, and the test set so far, S.  It
% should return two logical values.  If X is true, item I will be excluded
% from further consideration as a potential training item.  If R is true, F
% will be rescheduled again to check for exclusions on the next round of
% training item selection.  If R is false, F will be descheduled so that
% subsequent rounds will not have to perform needless checks.
%
% The function F should return TRUE if item I should be excluded from
% further consideration as a potential training item, otherwise FALSE.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

% if ~strcmpi(r,'once') && ~strcmpi(r,'repeat') && ~strcmpi(r,'conditional'),
%     error('Re-schedule flag must be ''once'', ''repeat'', or ''conditional''');
% end

train.exclusion_task(end+1).name = xname;
train.exclusion_task(end).func = f;
% train.exclusion_task(end).reschedule = r;

end