function g = train_chfreq_fit(train)
% TRAIN_CHFREQ_FIT - Compute goodness of fit for training set chunk
% frequencies
%
% G = train_chfreq_update(T)
%
% T specifies training set structure.  
%
% Chunk frequencies are evaluated by comparing the pre-computed
% frequencies for T to the target frequencies.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

% n_train = sum(train.items);
n_sizes = length(train.chfreq);

g = 0;

for ch_idx = 1:n_sizes,
    freq = reshape(train.chfreq{ch_idx}, 1, []);
    tgt_f = train.freq_tgt(ch_idx).freq;

    abstgt = (tgt_f < 0);
    tgt_f(abstgt) = -tgt_f(abstgt); % Magnitudes specify the targets

    total = sum(freq);
    total_tgt = sum(tgt_f);

    if any(abstgt) && total > total_tgt,
        % scale relative target freqs according to sample size
        % but do not scale absolute target freqs
        total_abs = sum(tgt_f(abstgt));
        tgt_f(~abstgt) = (total - total_abs) .* tgt_f(~abstgt) ./ ...
            (total_tgt - total_abs);
    else
        % no absolute target freqs, or else
        % small sample, treat relative freqs as absolute
        tgt_f = total .* tgt_f ./ total_tgt;
    end

    [nil, fit_raw] = likelihoodchi2(freq, tgt_f);
    nz = find(fit_raw); % In case some WTS are Inf, which could yield NaN
%     g = g + sum(fit_raw(nz) .* train.freq_tgt(ch_idx).wt(nz));
    cur_g = sum(fit_raw(nz) .* train.freq_tgt(ch_idx).wt(nz));
    % normalize for number of chunks and training items
    n_chunks = sum(freq);
%     cur_g = cur_g * n_train / n_chunks;
    if n_chunks,
        cur_g = cur_g ./ n_chunks;
        g = g + cur_g;
    end
end
if n_sizes,
    g = g ./ n_sizes;
end

end
