function train = train_chfreq_update(train, trainitems, newitem)
% TRAIN_CHFREQ_UPDATE - Updates chfreq for adding a new training item
%
% T = train_chfreq_update(T, M, I)
%
% T is the current training set structure.
% M is a structure array of training set items.
% I is the new item being added to the training set.
%
% New chunk frequencies are computed by adding the pre-computed
% frequencies for I to the pre-computed frequencies for T.
% [NB This strategy is based on the assumption that the number of symbols
% is reasonably small, so that the memory requirements of storing
% pre-computed frequencies for every potential item are modest.  However,
% the NGRAM function is quite efficient, and it might not sacrifice too
% much time to call ngram anew for the item, or even for the whole set of
% training items after adding the new item.]
%
% The CHFREQ field of T is changed to reflect the new chunk frequencies.

% Copyright 2007 Todd M. Bailey
%
% This file is part of AGL StimSelect (AGLSS).
%
%     AGLSS is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     AGLSS is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

n_train = train.n_items;
% loop through all required chunk sizes
for ch_idx = 1:length(newitem.chfreq),
    if n_train > 0,
        train.chfreq{ch_idx} = train.chfreq{ch_idx} + ...
            newitem.chfreq{ch_idx};
    else
        train.chfreq{ch_idx} = newitem.chfreq{ch_idx};
    end
end

end
